ScreenActionsConsumer class abstract

Inheritance

Constructors

ScreenActionsConsumer()

Properties

hashCode int
The hash code for this object.
no setterinherited
mainPadID int
no setter
padIDs List<int>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

accept(AbstractGameActionEvent gameEvent, PadActionEvent padEvent, int padID) → void
inherited
focus(int padID) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
unfocus(int padID) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited