KeyboardActionsLisenter class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- KeyboardActionsLisenter
Constructors
-
KeyboardActionsLisenter({required Widget child, required TextEditingController controller, KeyEventTransfer? keyEventTransfer, List<
Widget> ? floatings, FocusNode? keyboardFocus, FocusNode? textfieldFocus, PadActionDispatcher? dispatcher, void onPadEvent(PadActionEvent, String)?, EnableBindPadID setAWSD = (true, 1), EnableBindPadID setArrows = (true, 2), EnableBindPadID setNumpad = (true, 3), EnableBindPadID setIINEArrow = (true, 1), EnableBindPadID setJIKL = (true, 4)}) -
const
Properties
- child → Widget
-
final
- controller → TextEditingController
-
final
- dispatcher → PadActionDispatcher?
-
final
-
floatings
→ List<
Widget> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- keyboardFocus → FocusNode?
-
final
- keyEventTransfer → KeyEventTransfer?
-
final
- onPadEvent → void Function(PadActionEvent, String)?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- setArrows → EnableBindPadID
-
final
- setAWSD → EnableBindPadID
-
final
- setIINEArrow → EnableBindPadID
-
final
- setJIKL → EnableBindPadID
-
final
- setNumpad → EnableBindPadID
-
final
- textfieldFocus → FocusNode?
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
dispatchCall(
PadActionEvent event, int playerID) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
textDispatchCall(
PadActionEvent event, int playerID) → void -
textFieldWrap(
Widget child) → dynamic -
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited