GameLoop class abstract

Implementers

Constructors

GameLoop()

Properties

ended bool
no setter
hashCode int
The hash code for this object.
no setterinherited
paused bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
started bool
no setter

Methods

beforeGameStart() → dynamic
gameEnd() → dynamic
结束游戏
gamePause() → dynamic
暂停游戏
gameResume() → dynamic
继续游戏
gameStart() → dynamic
开启游戏循环
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited