GameLoopAvailable class abstract

Inheritance

Constructors

GameLoopAvailable()

Properties

ended bool
no setterinherited
hasGame bool
no setter
hashCode int
The hash code for this object.
no setterinherited
paused bool
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
started bool
no setterinherited

Methods

beforeGameStart() → dynamic
inherited
gameEnd() → dynamic
结束游戏
inherited
gamePause() → dynamic
暂停游戏
inherited
gameResume() → dynamic
继续游戏
inherited
gameStart() → dynamic
开启游戏循环
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited