DebuggerSafeUpdater mixin

Properties

debugInfo String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
update → void Function(VoidCallback c, [String? d])
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
safeUpdate(VoidCallback callback, {String? debugInfo, int frames = 1}) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited