GridUnit class

单元格信息

Constructors

GridUnit({required GridPos posGetter(GridPos axis), GridPos offsetPos = GridZero, Paint? decorate})
const
GridUnit.axisExchange(GridUnit copied, GridPos changeBefore, GridPos changeAfter)
该工厂方法将 parentPos 设置成 offset 后的偏移后的坐标值,不改变原始 pos 自身坐标系 有利于 以 group方式 添加到 parent group 之后保留原来 group 的原始坐标信息 同一个 Unit 最多存在两个 Group 中,父亲和当前 Group 否则会丢失信息
factory
GridUnit.offset({required GridPos offset, Paint? decorate})
factory

Properties

decorate Paint?
final
hashCode int
The hash code for this object.
no setterinherited
offsetPos GridPos
final
posGetter GridPos Function(GridPos axis)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

changeAxis(GridPos axisBefore, GridPos axisAfter) GridUnit
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
offset(GridPos offset) GridUnit
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited