ContextPageBuilder class abstract

Constructors

ContextPageBuilder()

Properties

contextPageName String
语义化的页面名称,用于 map 存储的 key 键
no setter
hashCode int
The hash code for this object.
no setterinherited
pageBuilder → WidgetsBuilder
执行的代理方法 build 时执行
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
update → void Function(VoidCallback )
更新页面调用的方法, 通常是 State.setState; 也可以是 notifyListeners
no setter

Methods

init() → void
用于过滤屏幕语境 子类实现 initState 时执行, 于 build 之前
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited