GridContextNavPageBuilder<T extends GridContext> class
abstract
Methods
-
build(BuildContext context)
→ Widget
-
Describes the part of the user interface represented by this widget.
inherited
-
createElement()
→ StatelessElement
-
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
createFromMatrix(MatrixRectGetter getRect, Rect measured)
→ WidgetsBuilder
-
子类需要实现
-
debugDescribeChildren()
→ List<DiagnosticsNode>
-
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(DiagnosticPropertiesBuilder properties)
→ void
-
Add additional properties associated with the node.
inherited
-
difference(MultiColumns target)
→ List<int>
-
inherited
-
intersection(MultiColumns target)
→ List<int>
-
inherited
-
matrixRectGetter(int xIndex, int yIndex, {int? toXIndex, int? toYIndex, String? named, Size? sampleSortSize})
→ RectGetter
-
进行逻辑坐标系到矩阵坐标系转换
-
namedMatrix({bool reverseX = false, bool reverseY = false, required String named, Size? sampleSortSize})
→ List<List<RectGetter>>
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
onCreate()
→ void
-
inherited
-
onDestroy()
→ void
-
inherited
-
onMeasured(ScreenContext screen)
→ void
-
override
-
onPause()
→ void
-
inherited
-
onReceive(Map<String, String>? params)
→ void
-
inherited
-
onResume()
→ void
-
inherited
-
onScreenWillChange(ScreenPT willChangePT)
→ void
-
override
-
onStateInit(void stateUpdater(VoidCallback c, [String? d]))
→ void
-
override
-
screenBuild(BuildContext context, ContextAccessor ctxAccessor, ScreenPT screenPT)
→ List<Widget>?
-
override
-
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style})
→ DiagnosticsNode
-
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString({DiagnosticLevel minLevel = DiagnosticLevel.info})
→ String
-
A string representation of this object.
inherited
-
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65})
→ String
-
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug})
→ String
-
Returns a one-line detailed description of the object.
inherited
-
toStringShort()
→ String
-
A short, textual description of this widget.
inherited
-
union(MultiColumns target)
→ List<int>
-
inherited
-
updateGridContext([Rect? measured])
→ T
-
-
willPlayAnimated({ScreenPT? fromPT, required ScreenPT toPT, required AnimationController animCtrl})
→ AnimationController
-
inherited